"use strict";
/*
 * Copyright (c) 2021, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const core_2 = require("@salesforce/core");
const kit_1 = require("@salesforce/kit");
const orgs_1 = require("../../utils/orgs");
const componentSetBuilder_1 = require("../../utils/componentSetBuilder");
const tableBuilder_1 = require("../../utils/tableBuilder");
core_2.Messages.importMessagesDirectory(__dirname);
const messages = core_2.Messages.loadMessages('@salesforce/plugin-deploy-retrieve-metadata', 'retrieve.metadata');
class RetrieveMetadata extends core_1.Command {
    async run() {
        const flags = (await this.parse(RetrieveMetadata)).flags;
        const componentSet = await componentSetBuilder_1.ComponentSetBuilder.build({
            apiversion: flags['api-version'],
            directory: flags['source-dir'],
            packagenames: flags['package-name'],
            manifest: (flags.manifest && {
                manifestPath: flags.manifest,
                directoryPaths: await orgs_1.getPackageDirs(),
            }),
            metadata: flags.metadata && {
                metadataEntries: flags.metadata,
                directoryPaths: await orgs_1.getPackageDirs(),
            },
        });
        const project = await core_2.SfdxProject.resolve();
        const retrieve = await componentSet.retrieve({
            usernameOrConnection: await orgs_1.resolveTargetOrg(flags['target-org']),
            merge: true,
            output: project.getDefaultPackage().fullPath,
            packageNames: flags['package-name'],
        });
        await retrieve.start();
        const result = await retrieve.pollStatus(500, kit_1.Duration.minutes(flags.wait).seconds);
        const fileResponses = (result === null || result === void 0 ? void 0 : result.getFileResponses()) || [];
        if (!flags.json) {
            tableBuilder_1.displayHumanReadableResults(fileResponses);
        }
        return fileResponses;
    }
}
exports.default = RetrieveMetadata;
RetrieveMetadata.summary = messages.getMessage('summary');
RetrieveMetadata.description = messages.getMessage('description');
RetrieveMetadata.examples = messages.getMessages('examples');
RetrieveMetadata.flags = {
    'api-version': core_1.Flags.string({
        char: 'a',
        summary: messages.getMessage('flags.api-version.summary'),
    }),
    manifest: core_1.Flags.string({
        char: 'x',
        summary: messages.getMessage('flags.manifest.summary'),
        exclusive: ['metadata', 'source-dir'],
    }),
    metadata: core_1.Flags.string({
        char: 'm',
        summary: messages.getMessage('flags.metadata.summary'),
        multiple: true,
        exclusive: ['manifest', 'source-dir'],
    }),
    'package-name': core_1.Flags.string({
        char: 'n',
        summary: messages.getMessage('flags.package-name.summary'),
        multiple: true,
    }),
    'source-dir': core_1.Flags.string({
        char: 'd',
        summary: messages.getMessage('flags.source-dir.summary'),
        multiple: true,
        exclusive: ['manifest', 'metadata'],
    }),
    'target-org': core_1.Flags.string({
        char: 't',
        summary: messages.getMessage('flags.target-org.summary'),
    }),
    wait: core_1.Flags.integer({
        char: 'w',
        default: 33,
        summary: messages.getMessage('flags.wait.summary'),
    }),
};
//# sourceMappingURL=metadata.js.map